# vim: set fileencoding=utf-8 :
###############################################################################
#                                                                             #
# Copyright (c) 2019 Idiap Research Institute, http://www.idiap.ch/           #
# Contact: beat.support@idiap.ch                                              #
#                                                                             #
# This file is part of the beat.editor module of the BEAT platform.           #
#                                                                             #
# Commercial License Usage                                                    #
# Licensees holding valid commercial BEAT licenses may use this file in       #
# accordance with the terms contained in a written agreement between you      #
# and Idiap. For further information contact tto@idiap.ch                     #
#                                                                             #
# Alternatively, this file may be used under the terms of the GNU Affero      #
# Public License version 3 as published by the Free Software and appearing    #
# in the file LICENSE.AGPL included in the packaging of this file.            #
# The BEAT platform is distributed in the hope that it will be useful, but    #
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  #
# or FITNESS FOR A PARTICULAR PURPOSE.                                        #
#                                                                             #
# You should have received a copy of the GNU Affero Public License along      #
# with the BEAT platform. If not, see http://www.gnu.org/licenses/.           #
#                                                                             #
###############################################################################

from ..backend.assetmodel import AssetModel


class TestAssetModel:
    """Test that the mock editor works correctly"""

    def test_model_load(self, qtbot, test_prefix):
        model = AssetModel()
        asset_type = AssetModel.Dataformat

        with qtbot.waitSignals(
            [model.assetTypeChanged, model.prefixPathChanged]
        ) as blocker:
            model.asset_type = asset_type
            model.prefix_path = test_prefix

        assert blocker.all_signals_and_args[0].args[0] == asset_type
        assert blocker.all_signals_and_args[1].args[0] == test_prefix

        asset_list = model.stringList()
        for item in asset_list:
            assert len(item.split("/")) == 3

    def test_experiment_model_load(self, qtbot, test_prefix):
        model = AssetModel()
        asset_type = AssetModel.Experiment

        with qtbot.waitSignals(
            [model.assetTypeChanged, model.prefixPathChanged]
        ) as blocker:
            model.asset_type = asset_type
            model.prefix_path = test_prefix

        assert blocker.all_signals_and_args[0].args[0] == asset_type
        assert blocker.all_signals_and_args[1].args[0] == test_prefix

        asset_list = model.stringList()

        for item in asset_list:
            assert len(item.split("/")) == 5
